@@ -300,6 +300,10 @@ class RedirectAnswer(Answer):
     def location(self):
         return self.headers['Location']
 
+    @classmethod
+    def get_class_status_code(cls) -> HttpStatusCode:
+        return HttpStatusCode.Found
+
 
 class FileAnswer(Answer):
     def __init__(self,
