@@ -7,7 +7,7 @@
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
 #
 import logging
-from asyncio import TimeoutError, Semaphore
+from asyncio import TimeoutError
 from enum import unique, StrEnum
 from typing import Union, Optional, Any, Mapping
 
@@ -15,14 +15,14 @@ from aiohttp import ClientResponse, ClientSession, BasicAuth, ClientTimeout, hdr
 from aiohttp.web_exceptions import HTTPBadRequest, HTTPUnauthorized, HTTPForbidden, HTTPNotFound, \
     HTTPUnprocessableEntity, HTTPBadGateway, HTTPServiceUnavailable, HTTPGatewayTimeout, HTTPInternalServerError, \
     HTTPError
-from async_tools import AsyncOnStop, DummyAsyncContextManager
+from async_tools import AsyncOnStop
 
-from http_tools.digest_auth import DigestAuth
-from http_tools.decoder import Decoder
-from http_tools.decoder_register import DecoderRegister
-from http_tools.header_utils import parse_content_type_header
-from http_tools.http_status_codes import HttpStatusCode
-from http_tools.mime_types import ContentType
+from .digest_auth import DigestAuth
+from .decoder import Decoder
+from .decoder_register import DecoderRegister
+from .header_utils import parse_content_type_header
+from .http_status_codes import HttpStatusCode
+from .mime_types import ContentType
 
 logger = logging.getLogger(__name__)
 
@@ -31,10 +31,11 @@ class HttpClient(AsyncOnStop):
     @unique
     class Method(StrEnum):
         GET = 'GET'
-        POST = 'POST'
+        HEAD = 'HEAD'
         PUT = 'PUT'
-        DELETE = 'DELETE'
+        POST = 'POST'
         PATCH = 'PATCH'
+        DELETE = 'DELETE'
 
     def __init__(self, session: Optional[ClientSession], default_timeout_sec: float = 100):
         self._session = session
@@ -57,20 +58,18 @@ class HttpClient(AsyncOnStop):
         return await self.request(self.Method.GET, url, params=params, timeout=timeout, auth=auth,
                                   headers=headers, force_decoder=force_decoder, proxy_url=proxy_url)
 
-    async def post(self,
+    async def head(self,
                    url: str,
                    *,
                    params: Optional[dict] = None,
-                   json: Union[dict, list, None] = None,
-                   data: Optional[bytes] = None,
                    headers: Optional[Mapping[str, str]] = None,
                    auth: Optional[BasicAuth] = None,
                    timeout: Optional[float] = None,
                    force_decoder: Decoder = None,
                    proxy_url: Optional[str] = None
                    ) -> Any:
-        return await self.request(self.Method.POST, url, params=params, json=json, data=data, timeout=timeout,
-                                  auth=auth, headers=headers, force_decoder=force_decoder, proxy_url=proxy_url)
+        return await self.request(self.Method.HEAD, url, params=params, timeout=timeout, auth=auth,
+                                  headers=headers, force_decoder=force_decoder, proxy_url=proxy_url)
 
     async def put(self,
                   url: str,
@@ -87,19 +86,19 @@ class HttpClient(AsyncOnStop):
         return await self.request(self.Method.PUT, url, params=params, json=json, data=data, timeout=timeout,
                                   auth=auth, headers=headers, force_decoder=force_decoder, proxy_url=proxy_url)
 
-    async def delete(self,
-                     url: str,
-                     *,
-                     params: Optional[dict] = None,
-                     json: Union[dict, list, None] = None,
-                     data: Optional[bytes] = None,
-                     headers: Optional[Mapping[str, str]] = None,
-                     auth: Optional[BasicAuth] = None,
-                     timeout: Optional[float] = None,
-                     force_decoder: Decoder = None,
-                     proxy_url: Optional[str] = None
-                     ) -> Any:
-        return await self.request(self.Method.DELETE, url, params=params, json=json, data=data, timeout=timeout,
+    async def post(self,
+                   url: str,
+                   *,
+                   params: Optional[dict] = None,
+                   json: Union[dict, list, None] = None,
+                   data: Optional[bytes] = None,
+                   headers: Optional[Mapping[str, str]] = None,
+                   auth: Optional[BasicAuth] = None,
+                   timeout: Optional[float] = None,
+                   force_decoder: Decoder = None,
+                   proxy_url: Optional[str] = None
+                   ) -> Any:
+        return await self.request(self.Method.POST, url, params=params, json=json, data=data, timeout=timeout,
                                   auth=auth, headers=headers, force_decoder=force_decoder, proxy_url=proxy_url)
 
     async def patch(self,
@@ -117,6 +116,21 @@ class HttpClient(AsyncOnStop):
         return await self.request(self.Method.PATCH, url, params=params, json=json, data=data, timeout=timeout,
                                   auth=auth, headers=headers, force_decoder=force_decoder, proxy_url=proxy_url)
 
+    async def delete(self,
+                     url: str,
+                     *,
+                     params: Optional[dict] = None,
+                     json: Union[dict, list, None] = None,
+                     data: Optional[bytes] = None,
+                     headers: Optional[Mapping[str, str]] = None,
+                     auth: Optional[BasicAuth] = None,
+                     timeout: Optional[float] = None,
+                     force_decoder: Decoder = None,
+                     proxy_url: Optional[str] = None
+                     ) -> Any:
+        return await self.request(self.Method.DELETE, url, params=params, json=json, data=data, timeout=timeout,
+                                  auth=auth, headers=headers, force_decoder=force_decoder, proxy_url=proxy_url)
+
     async def request(self,
                       method: Method,
                       url: str,
